# spotdlQt
A very simple gui application for spotdl to download music.

Written in python using [spotdl](https://github.com/spotDL/spotify-downloader) and [pyqt6](https://pypi.org/project/PyQt6/).

The icon.svg is downloaded from https://icons.getbootstrap.com/icons/spotify/.

# Examples
![screenshot1](screenshot1.png)
![screenshot2](screenshot2.png)
